@@ -7,10 +7,10 @@ lzma=$(which lzma 2> /dev/null) || true
 dar=$(which dar 2> /dev/null) || true
 tar=$(which tar 2> /dev/null) || true
 rsync=$(which rsync 2> /dev/null) || true
-mkisofs=$(which mkisofs 2> /dev/null) || true
+mkisofs=$(which mkisofs 2> /dev/null) || mkisofs=$(which genisoimage 2> /dev/null) || true
 growisofs=$(which growisofs 2> /dev/null) || true
 dvdrwformat=$(which dvd+rw-format 2> /dev/null) || true
-cdrecord=$(which cdrecord 2> /dev/null) || true
+cdrecord=$(which cdrecord 2> /dev/null) || cdrecord=$(which wodim 2> /dev/null) || true
 md5sum=$(which md5sum 2> /dev/null) || true
 bc=$(which bc 2> /dev/null) || true
 mysqldump=$(which mysqldump 2> /dev/null) || true
