@@ -17,13 +17,13 @@
 # If /usr/bin/gettext.sh is not found, we'll 
 # provide a dummy function.
 
-if [ -z "$libdir" ]; then
+if [[ -z "$libdir" ]]; then
     libdir="/usr/share/backup-manager"
 fi    
 libgettext="/usr/bin/gettext.sh"
 
-if [ ! -f $libgettext ]; then
-	. $libdir/gettext-dummy.sh
+if [[ ! -f $libgettext ]]; then
+    . $libdir/gettext-dummy.sh
 else
-	. $libdir/gettext-real.sh
+    . $libdir/gettext-real.sh
 fi
