@@ -24,7 +24,7 @@ function test_success()
 }
 
 # the conffile to test
-if [ -f ./backup-manager.conf ]; then
+if [[ -f ./backup-manager.conf ]]; then
     conffile="./backup-manager.conf"
     source $conffile
     source $libdir/sanitize.sh
@@ -37,7 +37,7 @@ nb_failure=0
 for file in t[0-9][0-9]*.sh
 do
         count
-        echo -n "[t $total] Running test $file:"
+        echo -n "[t $total] Running test $file: "
         
         if /bin/bash $file 2>/dev/null; then
             test_success $file
@@ -49,7 +49,7 @@ done
 echo "------------------------------------------------------------------------------"
 pct_success=$(($nb_success * 100 / $total))
 echo "Success score: $pct_success% ($nb_success/$total)"
-if [ "$nb_failure" -gt 0 ]; then
+if [[ "$nb_failure" -gt 0 ]]; then
     echo "Failed tests: $nb_failure"
 fi
 
