@@ -3,11 +3,12 @@
 set -e
 
 # Each test script should include testlib.sh
-source testlib.sh
+source "./testlib.sh"
 # When the test is ready, set this to false for nice outputs.
 # if you want to see what happens, use those flags
 # verbose="true"
 # warnings="true"
+# verbosedebug="true"
 
 # The conffile part of the test, see confs/* for details.
 source confs/base.conf
